betty.typing module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.typing module

Providing typing utilities.

betty.typing.internal(target: betty.typing.T) → betty.typing.T

  Mark a target as internal to Betty.

  Anything decorated with `@internal` MAY be used anywhere in Betty’s source code, but MUST be considered private by third-party code.

  This function is internal (and ironically cannot be decorated with itself).

  Parameters:

    target (`typing.TypeVar`(`T`))

  Return type:

    `typing.TypeVar`(`T`)